@@ -1,8 +1,6 @@
 use crate::build::{ConstType, ConstVal, ShadowConst};
 use crate::ci::CiType;
-use crate::date_time::DateTime;
 use crate::err::*;
-use crate::Format;
 use std::collections::BTreeMap;
 use std::io::{BufReader, Read};
 use std::path::Path;
@@ -135,10 +133,13 @@ impl Git {
         Ok(())
     }
 
+    #[allow(unused_variables)]
     fn init_git2(&mut self, path: &Path) -> SdResult<()> {
         #[cfg(feature = "git2")]
         {
+            use crate::date_time::DateTime;
             use crate::git::git2_mod::git_repo;
+            use crate::Format;
 
             let repo = git_repo(path).map_err(ShadowError::new)?;
             let reference = repo.head().map_err(ShadowError::new)?;
@@ -507,7 +508,6 @@ fn filter_git_dirty_stage(dirty_files: Vec<String>, staged_files: Vec<String>) -
 mod tests {
     use super::*;
     use crate::get_std_env;
-    use std::path::Path;
 
     #[test]
     fn test_git() {
@@ -534,7 +534,7 @@ mod tests {
 
     #[test]
     fn test_current_branch() {
-        if get_std_env().get("GITHUB_REF").is_some() {
+        if get_std_env().contains_key("GITHUB_REF") {
             return;
         }
         #[cfg(feature = "git2")]
